[PVFS2-CVS]
commit by rbross in pvfs2/src/io/bmi: bmi-types.h bmi.c bmi.h
reference-list.c reference-list.h
CVS commit program
cvs at parl.clemson.edu
Mon Feb 16 16:35:28 EST 2004
Update of /projects/cvsroot/pvfs2/src/io/bmi
In directory parlweb:/tmp/cvs-serv32729/src/io/bmi
Modified Files:
bmi-types.h bmi.c bmi.h reference-list.c reference-list.h
Log Message:
Move from bmi_addr_t to PVFS_BMI_addr_t for consistency.
Index: bmi-types.h
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/bmi/bmi-types.h,v
diff -p -u -r1.12 -r1.13
--- bmi-types.h 16 Feb 2004 21:22:41 -0000 1.12
+++ bmi-types.h 16 Feb 2004 21:35:28 -0000 1.13
@@ -19,7 +19,6 @@ typedef PVFS_size bmi_size_t; /* data re
typedef PVFS_msg_tag_t bmi_msg_tag_t; /* message tag */
typedef PVFS_context_id bmi_context_id; /* context identifier */
typedef PVFS_id_gen_t bmi_op_id_t; /* network operation handle */
-typedef PVFS_BMI_addr_t bmi_addr_t; /* network address handle */
/* TODO: not using a real type for this yet; need to specify what
* error codes look like */
Index: bmi.c
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/bmi/bmi.c,v
diff -p -u -r1.38 -r1.39
--- bmi.c 16 Feb 2004 16:23:44 -0000 1.38
+++ bmi.c 16 Feb 2004 21:35:28 -0000 1.39
@@ -503,7 +503,7 @@ void BMI_close_context(bmi_context_id co
* returns 0 on success, -errno on failure
*/
int BMI_post_recv(bmi_op_id_t * id,
- bmi_addr_t src,
+ PVFS_BMI_addr_t src,
void *buffer,
bmi_size_t expected_size,
bmi_size_t * actual_size,
@@ -546,7 +546,7 @@ int BMI_post_recv(bmi_op_id_t * id,
* returns 0 on success, -errno on failure
*/
int BMI_post_send(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *buffer,
bmi_size_t size,
enum bmi_buffer_type buffer_type,
@@ -587,7 +587,7 @@ int BMI_post_send(bmi_op_id_t * id,
* returns 0 on success, -errno on failure
*/
int BMI_post_sendunexpected(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *buffer,
bmi_size_t size,
enum bmi_buffer_type buffer_type,
@@ -983,7 +983,7 @@ int BMI_testcontext(int incount,
*
* returns pointer to string on success, NULL on failure
*/
-const char* BMI_addr_rev_lookup(bmi_addr_t addr)
+const char* BMI_addr_rev_lookup(PVFS_BMI_addr_t addr)
{
ref_st_p tmp_ref = NULL;
char* tmp_str = NULL;
@@ -1009,7 +1009,7 @@ const char* BMI_addr_rev_lookup(bmi_addr
*
* returns pointer to buffer on success, NULL on failure.
*/
-void *BMI_memalloc(bmi_addr_t addr,
+void *BMI_memalloc(PVFS_BMI_addr_t addr,
bmi_size_t size,
enum bmi_op_type send_recv)
{
@@ -1038,7 +1038,7 @@ void *BMI_memalloc(bmi_addr_t addr,
*
* returns 0 on success, -errno on failure
*/
-int BMI_memfree(bmi_addr_t addr,
+int BMI_memfree(PVFS_BMI_addr_t addr,
void *buffer,
bmi_size_t size,
enum bmi_op_type send_recv)
@@ -1068,7 +1068,7 @@ int BMI_memfree(bmi_addr_t addr,
*
* returns 0 on success, -errno on failure
*/
-int BMI_set_info(bmi_addr_t addr,
+int BMI_set_info(PVFS_BMI_addr_t addr,
int option,
void *inout_parameter)
{
@@ -1121,7 +1121,7 @@ int BMI_set_info(bmi_addr_t addr,
*
* returns 0 on success, -errno on failure
*/
-int BMI_get_info(bmi_addr_t addr,
+int BMI_get_info(PVFS_BMI_addr_t addr,
int option,
void *inout_parameter)
{
@@ -1212,7 +1212,7 @@ BMI_method_from_scheme(const char *uri)
*
* returns 0 on success, -errno on failure.
*/
-int BMI_addr_lookup(bmi_addr_t * new_addr,
+int BMI_addr_lookup(PVFS_BMI_addr_t * new_addr,
const char *id_string)
{
@@ -1314,7 +1314,7 @@ int BMI_addr_lookup(bmi_addr_t * new_add
* -errno on failure
*/
int BMI_post_send_list(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *const *buffer_list,
const bmi_size_t *size_list,
int list_count,
@@ -1383,7 +1383,7 @@ int BMI_post_send_list(bmi_op_id_t * id,
* -errno on failure
*/
int BMI_post_recv_list(bmi_op_id_t * id,
- bmi_addr_t src,
+ PVFS_BMI_addr_t src,
void *const *buffer_list,
const bmi_size_t *size_list,
int list_count,
@@ -1455,7 +1455,7 @@ int BMI_post_recv_list(bmi_op_id_t * id,
* -errno on failure
*/
int BMI_post_sendunexpected_list(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *const *buffer_list,
const bmi_size_t *size_list,
int list_count,
Index: bmi.h
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/bmi/bmi.h,v
diff -p -u -r1.21 -r1.22
--- bmi.h 21 Jan 2004 01:34:56 -0000 1.21
+++ bmi.h 16 Feb 2004 21:35:28 -0000 1.22
@@ -18,7 +18,7 @@
struct BMI_unexpected_info
{
bmi_error_code_t error_code;
- bmi_addr_t addr;
+ PVFS_BMI_addr_t addr;
void *buffer;
bmi_size_t size;
bmi_msg_tag_t tag;
@@ -35,7 +35,7 @@ int BMI_open_context(bmi_context_id* con
void BMI_close_context(bmi_context_id context_id);
int BMI_post_send(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *buffer,
bmi_size_t size,
enum bmi_buffer_type buffer_type,
@@ -44,7 +44,7 @@ int BMI_post_send(bmi_op_id_t * id,
bmi_context_id context_id);
int BMI_post_sendunexpected(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *buffer,
bmi_size_t size,
enum bmi_buffer_type buffer_type,
@@ -53,7 +53,7 @@ int BMI_post_sendunexpected(bmi_op_id_t
bmi_context_id context_id);
int BMI_post_recv(bmi_op_id_t * id,
- bmi_addr_t src,
+ PVFS_BMI_addr_t src,
void *buffer,
bmi_size_t expected_size,
bmi_size_t * actual_size,
@@ -94,32 +94,32 @@ int BMI_testcontext(int incount,
int max_idle_time_ms,
bmi_context_id context_id);
-void *BMI_memalloc(bmi_addr_t addr,
+void *BMI_memalloc(PVFS_BMI_addr_t addr,
bmi_size_t size,
enum bmi_op_type send_recv);
-int BMI_memfree(bmi_addr_t addr,
+int BMI_memfree(PVFS_BMI_addr_t addr,
void *buffer,
bmi_size_t size,
enum bmi_op_type send_recv);
-int BMI_set_info(bmi_addr_t addr,
+int BMI_set_info(PVFS_BMI_addr_t addr,
int option,
void *inout_parameter);
-int BMI_get_info(bmi_addr_t addr,
+int BMI_get_info(PVFS_BMI_addr_t addr,
int option,
void *inout_parameter);
const char *BMI_method_from_scheme(const char *uri);
-int BMI_addr_lookup(bmi_addr_t * new_addr,
+int BMI_addr_lookup(PVFS_BMI_addr_t * new_addr,
const char *id_string);
-const char* BMI_addr_rev_lookup(bmi_addr_t addr);
+const char* BMI_addr_rev_lookup(PVFS_BMI_addr_t addr);
int BMI_post_send_list(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *const *buffer_list,
const bmi_size_t* size_list,
int list_count,
@@ -131,7 +131,7 @@ int BMI_post_send_list(bmi_op_id_t * id,
bmi_context_id context_id);
int BMI_post_recv_list(bmi_op_id_t * id,
- bmi_addr_t src,
+ PVFS_BMI_addr_t src,
void *const *buffer_list,
const bmi_size_t *size_list,
int list_count,
@@ -145,7 +145,7 @@ int BMI_post_recv_list(bmi_op_id_t * id,
bmi_context_id context_id);
int BMI_post_sendunexpected_list(bmi_op_id_t * id,
- bmi_addr_t dest,
+ PVFS_BMI_addr_t dest,
const void *const *buffer_list,
const bmi_size_t *size_list,
int list_count,
Index: reference-list.c
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/bmi/reference-list.c,v
diff -p -u -r1.4 -r1.5
--- reference-list.c 2 Apr 2003 17:20:28 -0000 1.4
+++ reference-list.c 16 Feb 2004 21:35:28 -0000 1.5
@@ -61,12 +61,12 @@ void ref_list_add(ref_list_p rlp,
* ref_list_search_addr()
*
* looks for a reference structure in the list that matches the given
- * bmi_addr_t.
+ * PVFS_BMI_addr_t.
*
* returns a pointer to the structure on success, a NULL on failure.
*/
ref_st_p ref_list_search_addr(ref_list_p rlp,
- bmi_addr_t my_addr)
+ PVFS_BMI_addr_t my_addr)
{
ref_list_p tmp_link = NULL;
ref_st_p tmp_entry = NULL;
@@ -137,7 +137,7 @@ ref_st_p ref_list_search_str(ref_list_p
* returns a pointer to the structure on success, a NULL on failure.
*/
ref_st_p ref_list_rem(ref_list_p rlp,
- bmi_addr_t my_addr)
+ PVFS_BMI_addr_t my_addr)
{
ref_list_p tmp_link = NULL;
ref_list_p scratch = NULL;
Index: reference-list.h
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/bmi/reference-list.h,v
diff -p -u -r1.4 -r1.5
--- reference-list.h 2 Apr 2003 17:20:28 -0000 1.4
+++ reference-list.h 16 Feb 2004 21:35:28 -0000 1.5
@@ -7,7 +7,7 @@
/*
* Header file for reference list management functions. Reference structures
* are used to maintain the mapping between bmi_addr_t and
* method_addr_p addresses.
*/
@@ -27,7 +27,7 @@ typedef struct qlist_head *ref_list_p;
*/
struct ref_st
{
- bmi_addr_t bmi_addr; /* the identifier passed out of the BMI layer */
+ PVFS_BMI_addr_t bmi_addr; /* the identifier passed out of the BMI layer */
char *id_string; /* the id string that represents this reference */
method_addr_p method_addr; /* address structure used by the method */
@@ -48,9 +48,9 @@ ref_list_p ref_list_new(void);
void ref_list_add(ref_list_p rlp,
ref_st_p rsp);
ref_st_p ref_list_search_addr(ref_list_p rlp,
- bmi_addr_t my_addr);
+ PVFS_BMI_addr_t my_addr);
ref_st_p ref_list_rem(ref_list_p rlp,
- bmi_addr_t my_addr);
+ PVFS_BMI_addr_t my_addr);
ref_st_p ref_list_search_method_addr(ref_list_p rlp,
method_addr_p map);
ref_st_p ref_list_search_str(ref_list_p rlp,
@@ -7,7 +7,7 @@
/*
* Header file for reference list management functions. Reference structures
- * are used to maintain the mapping between bmi_addr_t and
+ * are used to maintain the mapping between PVFS_BMI_addr_t and
* method_addr_p addresses.
*/
More information about the PVFS2-CVS
mailing list